@@ -12,7 +12,7 @@ __docformat__ = 'restructuredtext'
 
 import numpy as np
 
-from pkshared.tools.refdata import atomic_masses, atomic_mass_symbol_map, \
+from ..tools.refdata import atomic_masses, atomic_mass_symbol_map, \
     atomic_numbers, atomic_number_symbol_map, element_symbols
 
 __all__ = ['Atom', 'AtomAttributes']
