@@ -15,7 +15,10 @@ from abc import ABCMeta, abstractmethod
 from collections import OrderedDict
 
 from ..chemistry import Atoms
+from sknano.version import short_version as version
 
+default_comment_line = \
+    'Structure data generated using scikit-nano version {}'.format(version)
 supported_structure_formats = ('xyz', 'data')
 default_structure_format = 'xyz'
 
@@ -23,8 +26,9 @@ __all__ = ['StructureData', 'StructureDataError',
            'StructureReader', 'StructureWriter',
            'StructureReaderError', 'StructureInputError',
            'StructureWriterError', 'StructureOutputError',
-           'StructureFormatError', 'supported_structure_formats',
-           'default_structure_format']
+           'StructureFormatError',
+           'supported_structure_formats', 'default_structure_format',
+           'default_comment_line']
 
 
 class StructureData(object):
@@ -36,15 +40,20 @@ class StructureData(object):
 
     """
     def __init__(self, fname=None):
-        self._atoms = Atoms()
-        self._comment_line = None
+        self._structure_atoms = Atoms()
+        self._comment_line = default_comment_line
         self._fname = fname
         self._properties = OrderedDict()
 
+    @property
+    def structure_atoms(self):
+        """:py:class:`~sknano.chemistry.Atoms` instance."""
+        return self._structure_atoms
+
     @property
     def atoms(self):
-        """:py:class:`Atoms` instance."""
-        return self._atoms
+        """Alias for :py:attr:`~StructureData.structure_atoms`."""
+        return self.structure_atoms
 
     @property
     def comment_line(self):
@@ -53,7 +62,7 @@ class StructureData(object):
 
     @comment_line.setter
     def comment_line(self, value=str):
-        """comment line setter.
+        """Set the comment line string.
 
         Parameters
         ----------
@@ -64,12 +73,12 @@ class StructureData(object):
 
     @property
     def fname(self):
-        """fname."""
+        """File name"""
         return self._fname
 
     @fname.setter
     def fname(self, value=str):
-        """fname setter.
+        """Set the file name string.
 
         Parameters
         ----------
@@ -80,13 +89,13 @@ class StructureData(object):
 
     @fname.deleter
     def fname(self):
-        """fname deleter."""
+        """Delete file name string"""
         del self._fname
 
     @property
     def Natoms(self):
-        """Number of atoms."""
-        return self._atoms.Natoms
+        """Number of atoms in :py:class:`~sknano.chemistry.Atoms`"""
+        return self._structure_atoms.Natoms
 
     @property
     def properties(self):
@@ -109,7 +118,7 @@ class StructureReader(StructureData):
 
     @abstractmethod
     def read(self):
-        """Read in structure data from file"""
+        """Read structure data from file"""
         return NotImplemented
 
 
@@ -119,7 +128,7 @@ class StructureWriter(object):
 
     @abstractmethod
     def write(self):
-        """Read in structure data from file"""
+        """Write structure data to file"""
         return NotImplemented
 
 
