@@ -6,22 +6,9 @@ Tools for analysis, helper functions, LUTs, etc. (:mod:`sknano.tools`)
 
 .. currentmodule:: sknano.tools
 
-.. versionadded:: 0.2.6
-   `GrapheneVacancyGenerator` and `NanotubeVacancyGenerator` implemented
-
 Contents
 ========
 
-Tools for manipulating nano-structures
---------------------------------------
-
-.. autosummary::
-   :toctree: generated/
-
-   VacancyGenerator
-   GrapheneVacancyGenerator
-   NanotubeVacancyGenerator
-
 Helper Functions
 -----------------
 
@@ -34,6 +21,9 @@ Helper Functions
    generate_Ch_list
    get_Ch_indices
    get_Ch_type
+   get_fpath
+   plural_word_check
+   rotation_matrix
    totient_func
 
 LUTs (Look-up 'tables' - lists and dictionaries)
@@ -45,13 +35,13 @@ LUTs (Look-up 'tables' - lists and dictionaries)
    chiral_type_name_mappings
    xyz_axes
 
-Custom exception classes for handling errors
---------------------------------------------
+Sub-packages
+============
 
 .. autosummary::
    :toctree: generated/
 
-   VacancyGeneratorError
+   refdata
 
 """
 from __future__ import division, print_function, absolute_import
@@ -60,6 +50,5 @@ __docformat__ = 'restructuredtext'
 
 from ._funcs import *
 from ._luts import *
-from ._vacancy_generator import *
 
 __all__ = [s for s in dir() if not s.startswith('_')]
