@@ -10,15 +10,17 @@ Helper functions (:mod:`sknano.tools._funcs`)
 from __future__ import division, print_function, absolute_import
 
 from fractions import gcd
+import os
 import re
+import sys
 
 import numpy as np
 
 from ._luts import chiral_type_name_mappings as Ch_types
 
 __all__ = ['cmp_Ch', 'filter_Ch', 'filter_Ch_list', 'filter_key_type_mappings',
-           'generate_Ch_list', 'get_Ch_indices', 'get_Ch_type', 'totient_func']
-
+           'generate_Ch_list', 'get_Ch_indices', 'get_Ch_type',
+           'get_fpath', 'plural_word_check', 'rotation_matrix', 'totient_func']
 
 filter_key_type_mappings = {}
 filter_key_type_mappings['Ch_type'] = str
@@ -419,6 +421,191 @@ def generate_Ch_list(ns=None, ni=None, nf=None, dn=None,
         return Ch_list
 
 
+def get_fpath(fname=None, ext=None, outpath=os.getcwd(), overwrite=False,
+              add_fnum=True, fnum=None, include_fname=False, fname_only=False,
+              verbose=False):
+    """Generate modified `fname` string based on chosen parameters.
+
+    Parameters
+    ----------
+    fname : str
+        Name of file, with or without an extension.
+    ext : str, optional
+        File extension to append to `fname`. If `ext` is None,
+        then `fname` is analyzed to see if it likely already has an
+        extension. An extension is set to the
+        last element in the list of strings returned by
+        `fname.split('.')` **if** this list has more than 1 element.
+        Otherwise, `ext` will be set to an empty string `''`.
+        If `ext` is not None and is a valid string,
+        then `fname` is analyzed to see if it already ends with `ext`.
+        If `fname.endswith(ext)` is True from the start, then `ext` will
+        not be duplicately appended.
+    outpath : str, optional
+        Absolute or relative path for generated output file.
+        Default is the absolute path returned by `os.getcwd()`.
+    overwrite : bool, optional
+        If True, overwrite an existing file if it has the same generated
+        file path.
+    add_fnum : bool, optional
+        Append integer number to output file name, starting with **1**.
+    fnum : {None, int}, optional
+        Starting file number to append if `add_fnum` is True.
+
+        .. note::
+
+        If the generated file path exists and `overwrite` is False,
+        setting this parameter has no effect.
+
+    include_fname : bool, optional
+        If True, return `(fpath, fname)` tuple.
+    fname_only : bool, optional
+        If True, return only `fname`.
+    verbose : bool, optional
+        Show verbose output.
+
+    Returns
+    -------
+    fpath : str
+        The concatenation of `outpath` followed by the updated `fname`.
+    (fpath, fname) : tuple (only if `include_fname` is True)
+        2-tuple of strings `(fpath, fname)`.
+    fname : str (only if `fname_only` is True)
+        Updated `fname`.
+
+    """
+    f = None
+    if fname is None or fname == '':
+        error_msg = '`fname` must be a string at least 1 character long.'
+        if fname is None:
+            raise TypeError(error_msg)
+        else:
+            raise ValueError(error_msg)
+    else:
+        f = fname
+        fsplit = f.split('.')
+        if ext is None:
+            if len(fsplit) > 1:
+                ext = '.' + fsplit[-1]
+            else:
+                ext = ''
+        else:
+            # check if extension already starts with a '.'
+            if not ext.startswith('.'):
+                ext = '.' + ext
+            # check if file name already ends with extension.
+            if f.split('.')[-1] != ext.split('.')[-1]:
+                f += ext
+
+    if add_fnum:
+        fname = re.split(ext, f)[0]
+        if fnum is not None:
+            f = fname + '-{:d}'.format(fnum) + ext
+        else:
+            f = fname + '-1' + ext
+
+    fpath = None
+
+    try:
+        os.makedirs(outpath)
+    except OSError:
+        if os.path.isdir(outpath):
+            pass
+        else:
+            outpath = os.curdir
+    finally:
+        fname = f
+        fpath = os.path.join(outpath, fname)
+        if os.path.isfile(fpath):
+            if overwrite:
+                try:
+                    os.remove(fpath)
+                except OSError as e:
+                    print(e)
+                    sys.exit(1)
+                else:
+                    if verbose:
+                        print(u'overwriting existing file: {}'.format(fname))
+            else:
+                if add_fnum:
+                    while os.path.isfile(fpath):
+                        fname = \
+                            '-'.join(re.split('-', re.split(ext, f)[0])[:-1])
+                        fnum = re.split('-', re.split(ext, f)[0])[-1]
+                        f = fname + '-' + str(int(fnum) + 1) + ext
+                        fpath = os.path.join(outpath, f)
+                    fname = f
+                else:
+                    print(u'file exists: {}\n'.format(fpath) +
+                          u'Set `add_fnum=True` to generate unique `fname`\n'
+                          u'or `overwrite=True` to overwrite existing '
+                          u'file.')
+                    fpath = None
+
+        if verbose:
+            print(u'Generated file name: {}'.format(fname))
+            print(u'File path: {}'.format(fpath))
+
+        if fname_only:
+            return fname
+        elif include_fname:
+            return fpath, fname
+        else:
+            return fpath
+
+
+def plural_word_check(word, count):
+    """Make a word plural by adding an *s* if `count` != 1.
+
+    Parameters
+    ----------
+    word : str
+        the word
+    count : int
+        the word count
+
+    Returns
+    -------
+    str
+
+    """
+    return word if count == 1 else word + 's'
+
+
+def rotation_matrix(angle, rot_axis='z', deg2rad=False):
+    """Generate a rotation matrix.
+
+    Parameters
+    ----------
+    angle : float
+        rotation angle in radians
+    rot_axis : {'x', 'y', 'z'}, optional
+        rotation axis
+    deg2rad : bool, optional
+        Angle is in degrees and needs to be converted to radians
+
+    Returns
+    -------
+    ndarray
+        rotation matrix
+
+    """
+    if deg2rad:
+        angle = np.radians(angle)
+    if rot_axis == 'x':
+        return np.array([[1, 0, 0],
+                         [0, np.cos(angle), -np.sin(angle)],
+                         [0, np.sin(angle), np.cos(angle)]])
+    elif rot_axis == 'y':
+        return np.array([[np.cos(angle), 0, np.sin(angle)],
+                         [0, 1, 0],
+                         [-np.sin(angle), 0, np.cos(angle)]])
+    else:
+        return np.array([[np.cos(angle), -np.sin(angle), 0],
+                         [np.sin(angle), np.cos(angle), 0],
+                         [0, 0, 1]])
+
+
 def totient_func(n=int):
     """Compute the totatives of :math:`n`.
 
